@@ -2,8 +2,8 @@ from typing import Dict
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 from FreeTAKServer.model.RawCoT import RawCoT
-loggingConstants = LoggingConstants()
-logger = CreateLoggerController("SendDataController").getLogger()
+loggingConstants = LoggingConstants(log_name="FTS_SendDataController")
+logger = CreateLoggerController("FTS_SendDataController", logging_constants=loggingConstants).getLogger()
 import copy
 #TODO: the part handling new connection from seperate process needs to be cleaned up
 
@@ -46,7 +46,7 @@ class SendDataController:
                 shareDataPipe.put([copiedProcessedCoTObject])
                 return 1
             
-            elif (hasattr(processedCoT.modelObject.detail, "marti") and len(processedCoT.modelObject.detail.marti.dest) > 1) or (hasattr(processedCoT.modelObject.detail, "_chat") and processedCoT.modelObject.detail._chat.chatgrp.uid1 != "All Chat Rooms"): # this needs to check that val is greater than one because parsing automatically adds 1 dest value
+            elif self.has_valid_marti(processedCoT): # this needs to check that val is greater than one because parsing automatically adds 1 dest value
                 self.returnData = self.send_to_specific_client(clientInformationQueue, processedCoT, sender, shareDataPipe)
                 return self.returnData
             
@@ -60,19 +60,22 @@ class SendDataController:
 
     def send_to_specific_client(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
+            dests = [dest.callsign for dest in processedCoT.modelObject.detail.marti.dest]
             if not (hasattr(processedCoT.modelObject.detail, "marti") and len(processedCoT.modelObject.detail.marti.dest) > 1) or (hasattr(processedCoT.modelObject.detail, "_chat") and processedCoT.modelObject.detail._chat.chatgrp.uid1 != "All Chat Rooms"):
                 # print('marti not present')
                 return self.send_to_all(clientInformationQueue, processedCoT, sender, shareDataPipe)
-
+            elif dests == [None] or dests == [None, None]:
+                return self.send_to_all(clientInformationQueue, processedCoT, sender, shareDataPipe)
             else:
                 # print('marti present')
-                for dest in processedCoT.modelObject.detail.marti.dest:
+                for dest in dests:
                     try:
-                        for client in clientInformationQueue.values():
-                            if client[1].m_presence.modelObject.detail.contact.callsign == dest.callsign:
+                        for client_id, client in clientInformationQueue.items():
+                            if client[1].m_presence.modelObject.detail.contact.callsign == dest:
                                 sock = client[0]
                                 try:
                                     sock.send(processedCoT.xmlString)
+                                    logger.info(str(processedCoT.xmlString)+" sent to client "+client_id)
                                 except Exception as e:
                                     logger.error('error sending data with marti to client data ' + str(
                                         processedCoT.xmlString) + 'error is ' + str(e))
@@ -95,7 +98,9 @@ class SendDataController:
             return -1
     def send_to_all(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
-            for client in clientInformationQueue.values():
+            for client_id, client in clientInformationQueue.items():
+                if processedCoT.type != "TakPong" and hasattr(sender, "user_id") and client_id == sender.user_id:
+                    continue
                 sock = client[0]
                 try:
                     if hasattr(processedCoT, 'xmlString'):
@@ -104,11 +109,13 @@ class SendDataController:
                             sock.send(processedCoT.xmlString)
                         except TypeError:
                             sock.send(processedCoT.xmlString.encode())
+                        logger.info(str(processedCoT.xmlString)+" sent to client "+client_id)
                     else:
                         try:
                             sock.send(processedCoT.idData)
                         except TypeError:
                             sock.send(processedCoT.idData.encode())
+                        logger.info(str(processedCoT.idData)+" sent to client "+client_id)
                 except Exception as e:
                     logger.error('error in sending of data ' + str(e))
                     return (-1, client[1])
@@ -146,6 +153,7 @@ class SendDataController:
                         logger.error('error sending data with marti to client within if data is ' + str(
                             processedCoT.xmlString) + 'error is ' + str(e))
                         return -1
+                logger.info("CoT sent "+str(processedCoT.modelObject.uid))
                 if shareDataPipe != None:
                     processedCoT.clientInformation = None
                     if hasattr(self, 'messages_to_core_count'):
@@ -155,4 +163,15 @@ class SendDataController:
                     pass
                 return 1
         except Exception as e:
-            logger.error('there has been an exception in sending geochat ' + str(e))
\ No newline at end of file
+            logger.error('there has been an exception in sending geochat ' + str(e))
+
+    def has_valid_marti(self, message):
+        if hasattr(message, "modelObject"):
+            if hasattr(message.modelObject.detail, "marti") and len(message.modelObject.detail.marti.dest) > 1:
+                return True
+            elif hasattr(message.modelObject.detail, "marti"):
+                if message.modelObject.detail.marti.dest[0].callsign != None and message.modelObject.detail.marti.dest[0].callsign != "":
+                    return True
+            elif hasattr(message.modelObject.detail, "_chat") and message.modelObject.detail._chat.chatgrp.uid1 != "All Chat Rooms":
+                return True
+            return False
\ No newline at end of file
