@@ -1,4 +1,5 @@
 class ReceiveConnectionsConstants:
     def __init__(self):
         self.RECEIVECONNECTIONDATATIMEOUT = 4
-        self.TESTDATA = b'<multiEvent>TEST</multiEvent>'
\ No newline at end of file
+        self.CONNECTION_DATA_BUFFER = 1024
+        self.TESTDATA = 'TEST'
\ No newline at end of file
